IMX_BIN_DETECT+=( glibc_compat )

glibc_compat() {
  local libc=$(dpkg-query -f '${Version}' -W libc6:arm64)
  if [[ -z "$libc" ]] || printf "%s\n" "2.33" "${libc%-*}" | sort -VC; then
    echo "Skipping libc_2.33_compat: not debian or libc6:arm64 >= 2.33 (or not installed)"
    return
  fi

  IMX_BIN_PACKAGE="libc233compat"
  IMX_BIN_VERSION=1.0
  TARGET="$PACKAGE_DIR/$IMX_BIN_PACKAGE"
  if [[ -e "$DEB_DIR/${IMX_BIN_PACKAGE}_${IMX_BIN_VERSION}-1_arm64.deb" ]]; then
    return
  fi
  mkdir -p "$TARGET/debian"

  cat > "$TARGET/libc_2.33_compat.c" <<'EOF'
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>

int stat(const char *pathname, struct stat *statbuf) {
        return __xstat(_STAT_VER, pathname, statbuf);
}

int fstat(int fd, struct stat *statbuf) {
        return __fxstat(_STAT_VER, fd, statbuf);
}
EOF
  cat > "$TARGET/Makefile" <<'EOF'
LDFLAGS = -Wl,--version-script=compat.map
CFLAGS = -fpic

all: libc_2.33_compat.so.0

libc_2.33_compat.so.0: libc_2.33_compat.c
	$(CC) -fpic -shared -o libc_2.33_compat.so.0 libc_2.33_compat.c

clean:
	rm -f libc_2.33_compat.so.0
EOF

  cat > "$TARGET/debian/changelog" <<EOF
libc233compat (1.0-1) experimental; urgency=low

  * Compat lib for glibc 2.33 with other at-imxlibpackages

 -- $MAINTAINER_NAME <$MAINTAINER_EMAIL>  $(date -R)
EOF

  cat > "$TARGET/debian/control" <<'EOF'
Source: libc233compat
Section: libs
Priority: optional
Maintainer: Dominique Martinet <dominique.martinet@atmark-techno.com>
Build-Depends: debhelper-compat (= 13)
Standards-Version: 4.5.1
Homepage: https://atmark-techno.com
Rules-Requires-Root: no

Package: libc233compat
Architecture: any
Multi-Arch: same
Depends: ${shlibs:Depends}, ${misc:Depends}
Description: stat and fstat wrappers for glibc 2.33
EOF
  cat > "$TARGET/debian/copyright" <<'EOF'
Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/

Files: *
Copyright: 2022 Atmark Techno, Inc
License: MIT
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sub license, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:
 .
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL
 THE COPYRIGHT HOLDERS, AUTHORS AND/OR ITS SUPPLIERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 USE OR OTHER DEALINGS IN THE SOFTWARE.
EOF
  cat > "$TARGET/debian/libc233compat.install" <<'EOF'
libc_2.33_compat.so.0 usr/lib/${DEB_HOST_MULTIARCH}/
EOF
  cat > "$TARGET/debian/rules" <<'EOF'
#!/usr/bin/make -f

DEB_HOST_MULTIARCH ?= $(shell dpkg-architecture -qDEB_HOST_MULTIARCH)

%:
	dh $@
EOF
  chmod +x "$TARGET/debian/rules"
  imx_lib_build

  sudo apt install "$DEB_DIR/${IMX_BIN_PACKAGE}_${IMX_BIN_VERSION}-1_arm64.deb"
}
