IMX_BIN_DETECT+=( isp_imx_detect )
BUILD_DEPENDS+=( "libdrm-dev:arm64" "libstdc++6:arm64" "libtinyxml2-dev:arm64" "cmake" "libwayland-dev:arm64" "patchelf" )
isp_imx_detect() {
	BIN_NAME=$(awk 'match($0, /^Package:\s+(isp-imx-[0-9][0-9ac-z.]*(-aarch64)?\.bin$)/, m){print m[1]}' "$META_IMX_DIR/$SCR_FILE")
	imx_lib_download_bin "$BIN_NAME"

	if [[ "$BIN_NAME" =~ ^(isp-imx)-([0-9][0-9ac-z.]*)(-aarch64)?(.bin)?$ ]]; then
		IMX_BIN_PACKAGE=${BASH_REMATCH[1]}
		IMX_BIN_VERSION=${BASH_REMATCH[2]}

		imx_bin_control=isp_imx_control
		imx_bin_install=isp_imx_install
		imx_bin_rules=isp_imx_rules
		imx_lib_package_run
	fi
}

# contents of debian/control file
isp_imx_control() {
	cat << EOF
Source: $IMX_BIN_PACKAGE
Section: non-free/libs
Priority: optional
Maintainer: $MAINTAINER_NAME <$MAINTAINER_EMAIL>
Build-Depends: debhelper-compat (= 12)
Standards-Version: 4.3.0
Rules-Requires-Root: no
Homepage: https://www.nxp.com/

Package: $IMX_BIN_PACKAGE
Section: non-free/libs
Architecture: arm64
Multi-Arch: same
Pre-Depends: \${misc:Pre-Depends}
Depends:
 \${misc:Depends},
 \${shlibs:Depends}
Description: i.MX Verisilicon Software ISP
 It can be downloaded from the following URL.
 https://www.nxp.com/lgfiles/NMG/MAD/YOCTO/$BIN_NAME
EOF

( cd "$TARGET" && patch -Np1 <<'EOF'
diff --git a/appshell/v4l_drm_test/CMakeLists.txt b/appshell/v4l_drm_test/CMakeLists.txt
index be4c4663ec53..f175445395ce 100644
--- a/appshell/v4l_drm_test/CMakeLists.txt
+++ b/appshell/v4l_drm_test/CMakeLists.txt
@@ -78,6 +78,7 @@ if ( NOT ANDROID )
     target_link_libraries ( drm_test ${LIB_PTHREAD_NAME} drm ${LIB_LOG_NAME})
     target_link_libraries ( video_test ${LIB_PTHREAD_NAME} drm yuv2rgb_static vvdisplay_shared ${LIB_LOG_NAME})
     target_link_libraries ( video_test ${LIB_PTHREAD_NAME}  jsoncpp_lib ${LIB_LOG_NAME})
+    target_link_libraries ( video_test ${LIB_PTHREAD_NAME}  wayland-client g2d ${LIB_LOG_NAME})
 else ()
     target_link_libraries ( drm_test ${LIB_PTHREAD_NAME} ${LIB_LOG_NAME} drm_android cutils base c++ )
     target_link_libraries ( video_test ${LIB_PTHREAD_NAME} yuv2rgb_static vvdisplay_shared ${LIB_LOG_NAME} drm_android cutils base c++ )
diff --git a/mediacontrol/daemon/CMakeLists.txt b/mediacontrol/daemon/CMakeLists.txt
index 909a45046aa2..8ab155bfd9bd 100644
--- a/mediacontrol/daemon/CMakeLists.txt
+++ b/mediacontrol/daemon/CMakeLists.txt
@@ -80,7 +80,7 @@ else (GENERATE_PARTITION_BUILD)
         ${LIB_ROOT}/${CMAKE_BUILD_TYPE}/lib/libcameric_drv.so
         ${LIB_ROOT}/${CMAKE_BUILD_TYPE}/lib/libhal.so
         ${LIB_ROOT}/${CMAKE_BUILD_TYPE}/lib/libbase64.so
-        ${SDKTARGETSYSROOT}/usr/lib/libtinyxml2.so
+        tinyxml2
         ${LIB_ROOT}/${CMAKE_BUILD_TYPE}/lib/libbufferpool.so
         ${LIB_ROOT}/${CMAKE_BUILD_TYPE}/lib/libcameric_reg_drv.so
         ${LIB_ROOT}/${CMAKE_BUILD_TYPE}/lib/libisi.so
EOF
) >&2
}

# contents of debian/install file
isp_imx_install() {
	cat << EOF
appshell/build/generated/release/lib/*.so* /usr/lib/aarch64-linux-gnu/
appshell/build/generated/release/include/* /usr/include/aarch64-linux-gnu/
EOF
}

# contents of debian/rules file
isp_imx_rules() {
	cat << 'EOF'
#!/usr/bin/make -f

%:
	dh $@ --builddirectory=appshell/build \
		--buildsystem=cmake

override_dh_auto_configure:
	sh -c 'dd bs=1M count=133832 iflag=count_bytes; echo 0: 9791960600000d003921010010000000 | xxd -r; dd bs=1M skip=16 iflag=skip_bytes' < units/cam_device/proprietories/lib/libcam_device.so > libcam_device.so
	patchelf --clear-symbol-version stat libcam_device.so
	patchelf --add-needed libc_2.33_compat.so.0 libcam_device.so
	mv libcam_device.so units/cam_device/proprietories/lib/libcam_device.so
	dh_auto_configure -- \
		-DCMAKE_SYSTEM_PROCESSOR=aarch64 \
		-DPLATFORM=ARM64 \
		-DCMAKE_SYSTEM_NAME=Linux \
		-DCMAKE_NO_SYSTEM_FROM_IMPORTED=1 \
		-DCMAKE_BUILD_TYPE=release \
		-DISP_VERSION=ISP8000NANO_V1802 \
		-DAPPMODE=V4L2 \
		-DQTLESS=1 \
		-DFULL_SRC_COMPILE=1 \
		-DWITH_DWE=1 \
		-DWITH_DRM=1 \
		-DSERVER_LESS=1 \
		-DSUBDEV_V4L2=1 \
		-DENABLE_IRQ=1 \
		-DPARTITION_BUILD=0 \
		-DSDKTARGETSYSROOT=/ \
		-DIMX_G2D=ON \
		-D3A_SRC_BUILD=0 \
		-DCMAKE_CXX_FLAGS="-I/usr/$(DEB_HOST_MULTIARCH)/include/drm" \
		.. -Wno-dev

override_dh_auto_install: ;

override_dh_shlibdeps:
	dh_shlibdeps -l/usr/lib/$(DEB_HOST_MULTIARCH):/usr/$(DEB_HOST_MULTIARCH)/lib

override_dh_dwz:
	dh_dwz --exclude=libcam_device.so
EOF
}
